export = Schedules;
declare const Schedules_base: {
    new (hueApi: any): import("./http/ApiDefinition");
};
declare class Schedules extends Schedules_base {
    constructor(hueApi: any);
    /**
     * Gets all the Schedules from the bridge.
     * @returns {Promise<Array<Schedule>>} A Promise that will resolve to an Array of Schedules.
     */
    getAll(): Promise<import("../model/Schedule")[]>;
    /**
     * @deprecated Use getSchedule(id) instead
     * @param id {int | Schedule}
     * @returns {Promise<Schedule>}
     */
    get(id: any): Promise<import("../model/Schedule")>;
    /**
     * Gets a specific Schedule from the Bridge.
     * @param id {int | Schedule} The id or Schedule instance to retrieve from the bridge.
     * @returns {Promise<Schedule>} A Promise that will resolve to the actual schedule instance.
     */
    getSchedule(id: any): Promise<import("../model/Schedule")>;
    /**
     *
     * @param name
     * @returns {Promise<Schedule[]>}
     */
    getScheduleByName(name: any): Promise<import("../model/Schedule")[]>;
    /**
     * Creates a new Schedule on the bridge.
     * @param schedule {Schedule} The instance to create on the bridge.
     * @returns {PromiseLike<Schedule> | Promise<Schedule>} The resultant Schedule instance that was created.
     */
    createSchedule(schedule: import("../model/Schedule")): Promise<import("../model/Schedule")> | PromiseLike<import("../model/Schedule")>;
    /**
     * Updates a Schedule.
     * @param schedule {Schedule}  The schedule with updated attributes to be saved to the Bridge.
     * @returns {Promise<Object>} A promise that will resolve to an Object of the keys that were the attrubutes updated
     * and a Boolean value that indicates if it was updated.
     */
    updateSchedule(schedule: import("../model/Schedule")): Promise<Object>;
    /**
     * Deletes an existing Schedule.
     * @param id {int | Schedule} The id or Schedule instance to delete.
     * @returns {Promise<boolean>} A Promise that will resolve to a boolean indicating success.
     */
    deleteSchedule(id: any): Promise<boolean>;
}
declare namespace Schedules {
    export { Schedule };
}
type Schedule = import("../model/Schedule");
